@@ -25,3 +25,8 @@ from .tracking_assumptions import post_tracking_assumptions_to_database
 from .tracking_assumptions import get_all_tracking_assumptions
 from .tracking_assumptions import get_index_tracking_assumption_history
 from .tracking_assumptions import get_most_recent_index_tracking_assumption
+
+from .factor_mapping import post_factor_baskets_to_database
+from .factor_mapping import get_all_factor_baskets
+from .factor_mapping import get_regional_factor_baskets
+from .factor_mapping import get_country_factor_baskets
