@@ -13,7 +13,7 @@ def post_index_name_acronyms_to_database(dataset: pd.DataFrame, access_token: st
     :param dataset: a Pandas DataFrame containing the data to upload within a given schema. (pd.DataFrame)
     :param access_token: the access token of the user, must be an active access token. (str)
     :param verbose: determines if status is printed. Default=True. (bool)
-    :return: N/A
+    :return: failed_uploads: the information which failed to upload. (pd.DataFrame)
     """
     if not isinstance(dataset, pd.DataFrame):
         raise TypeError("The 'dataset' argument must be a Pandas DataFrame.")
@@ -21,6 +21,7 @@ def post_index_name_acronyms_to_database(dataset: pd.DataFrame, access_token: st
         raise TypeError("The 'access_token' must be a string type.")
     if not isinstance(verbose, bool):
         raise TypeError("The 'verbose' argument must be a boolean argument.")
+    failed_uploads = []
     dict_list = dataset.to_dict('records')
     url = "https://www.samsonrockapis.com/namemapping/upload"
     header = {'Authorization': 'Bearer ' + access_token}
@@ -30,11 +31,14 @@ def post_index_name_acronyms_to_database(dataset: pd.DataFrame, access_token: st
             if verbose:
                 print("Status Code: {}, data posted to date table.".format(response.status_code))
         elif response.status_code == 401:
+            failed_uploads.append(item)
             if verbose:
                 print("Status Code: {}, user not authenticated for endpoint.".format(response.status_code))
         else:
+            failed_uploads.append(item)
             if verbose:
                 print("Status Code: {}, {}.".format(response.status_code, response.text))
+    return pd.DataFrame.from_records(failed_uploads)
 
 
 def get_index_name_acronyms_from_database(access_token: str, verbose: bool = True):
@@ -61,7 +65,7 @@ def get_index_name_acronyms_from_database(access_token: str, verbose: bool = Tru
         return pd.read_json(response.text)
     elif response.status_code == 404:
         if verbose:
-            print("Status Code: {}, cannot find Announcement data for this Index.".format(response.status_code))
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
     elif response.status_code == 401:
         if verbose:
